@@ -296,7 +296,7 @@ sub _build_class_arguments {
 
         # If we're hand-coding a render_as, hints or label, let's use it.
         for (
-            qw(render_as label hints max_length mandatory sort_order container documentation)
+            qw(render_as label hints display_length max_length mandatory sort_order container documentation)
             )
         {
             if ( defined( my $val = $column->$_ ) ) {
