@@ -1,6 +1,10 @@
 use warnings;
 use strict;
 
+package Jifty::Bootstrap;
+
+use base qw/Jifty::Object/;
+
 =head1 NAME
 
 Jifty::Bootstrap - Insert initial data into your database
@@ -12,7 +16,6 @@ bootstrapping.  Use it to set up initial data in your database when
 your application is first installed.
 
 =head1 EXAMPLE
-
  
  package MyApp::Bootstrap;
  use base 'Jifty::Bootstrap';
@@ -23,13 +26,6 @@ your application is first installed.
      $modelclass->create( name => 'Widget');
  }; 
  
- 
-=cut
-
-package Jifty::Bootstrap;
-
-use base qw/Jifty::Object/;
-
 =head2 run
 
 C<run> is the workhorse method for the Bootstrap class.  This takes care of
@@ -42,5 +38,15 @@ sub run {
     1;
 }
 
+=head1 SEE ALSO
+
+L<Jifty::Upgrade>, L<Jifty::Script::Schema>
+
+=head1 LICENSE
+
+Jifty is Copyright 2005-2006 Best Practical Solutions, LLC.
+Jifty is distributed under the same terms as Perl itself.
+
+=cut
 
 1;
