@@ -40,6 +40,8 @@ use Jifty::DateTime ();
 use Jifty::Record ();
 use Jifty::Collection ();
 use Jifty::Action ();
+use Jifty::Action::Autocomplete ();
+use Jifty::Action::Redirect ();
 use Jifty::Action::Record ();
 use Jifty::Action::Record::Create ();
 use Jifty::Action::Record::Update ();
@@ -95,9 +97,9 @@ use Jifty::Module::Pluggable;
 # we do the actual load in Jifty::Script
 Jifty::Module::Pluggable->import(
     search_path => ['Jifty::Plugin'],
-    file_regex  => qr{/Command/[^/]+},
+    file_regex  => qr{/Command/[^/]+\.pm},
     require     => 1,
-    sub_name    => "plugin_commands"
+    sub_name    => "plugin_commands",
 );
 
 =head1 SEE ALSO
