@@ -4,12 +4,9 @@ use warnings;
 package Jifty::Plugin::SkeletonApp;
 use base qw/Jifty::Plugin/;
 
-# Your plugin goes here.  If takes any configuration or arguments, you
-# probably want to override L<Jifty::Plugin/init>.
-
 =head1 NAME
 
-Jifty::Plugin::SkeletonApp
+Jifty::Plugin::SkeletonApp - Skeleton for your application
 
 =head1 DESCRIPTION
 
