@@ -6,10 +6,23 @@ use Apache2::Const -compile => qw(OK);
 use Jifty::Everything;
 use CGI;
 
+# XXX: can we turn it into a command line script and at the same time use it as
+# as handler?
+
 =head1 NAME
 
 Jifty::Script::ModPerl2 - a ModPerl2 handler for your jifty app.
 
+=head1 SYNOPSIS
+
+    <VirtualHost *:80>
+        DocumentRoot /path/to/base/dir/of/app
+        SetHandler perl-script
+        PerlHandler Jifty::Script::ModPerl2
+    </VirtualHost>
+
+Not a command line script. Read --man for more info.
+
 =head1 DESCRIPTION
 
 This handler should be used with Apache2 and ModPerl2.  It requires the
@@ -29,6 +42,8 @@ and should configure about the same.
 
 TODO: This should be set up to serv the static files without mod_perl.
 
+=head1 METTHODS
+
 =head2 handler
 
 The mod_perl handler for the app
@@ -52,7 +67,6 @@ sub handler {
     ##
     # Oll Korrect
     return Apache2::Const::OK;
-
 }
 
 1;
