@@ -1,10 +1,16 @@
 package Jifty::Web::Menu;
 
+use strict;
+use warnings;
+
+
 use base qw/Class::Accessor::Fast/;
 use URI;
-use Scalar::Util ();
+use Scalar::Util qw(weaken);
 
-__PACKAGE__->mk_accessors(qw(label parent sort_order link target escape_label class));
+__PACKAGE__->mk_accessors(qw(
+    label sort_order link target escape_label class render_children_inline
+));
 
 =head1 NAME
 
@@ -23,9 +29,18 @@ each option's use.
 
 sub new {
     my $package = shift;
-    # Class::Accessor only wants a hashref;
-    $package->SUPER::new( ref($_[0]) eq 'HASH' ? @_ : {@_} );
+    my $args = ref($_[0]) eq 'HASH' ? shift @_ : {@_};
 
+    my $parent = delete $args->{'parent'};
+    $args->{sort_order} ||= 0;
+
+    # Class::Accessor only wants a hashref;
+    my $self = $package->SUPER::new( $args );
+
+    # make sure our reference is weak
+    $self->parent($parent) if defined $parent;
+
+    return $self;
 }
 
 
@@ -35,23 +50,30 @@ Sets or returns the string that the menu item will be displayed as.
 
 =cut
 
-sub label {
-    my $self = shift;
-    $self->{label} = shift if @_;
-    return $self->{label};
-}
-
 =head2 parent [MENU]
 
 Gets or sets the parent L<Jifty::Web::Menu> of this item; this defaults
-to null.
+to null. This ensures that the reference is weakened.
+
+=cut
+
+
+sub parent {
+    my $self = shift;
+    if (@_) {
+        $self->{parent} = shift;
+        weaken $self->{parent};
+    }
+
+    return $self->{parent};
+}
+
 
 =head2 sort_order [NUMBER]
 
 Gets or sets the sort order of the item, as it will be displayed under
 the parent.  This defaults to adding onto the end.
 
-
 =head2 link
 
 Gets or set a Jifty::Web::Link object that represents this menu item. If
@@ -69,6 +91,16 @@ Get or set the frame or pseudo-target for this link. something like L<_blank>
 Gets or sets the CSS class the link should have in addition to the default
 classes.  This is only used if C<link> isn't specified.
 
+=head2 render_children_inline [BOOLEAN]
+
+Gets or sets whether children are rendered inline as a menu "group" instead
+of a true submenu.  Only used when rendering with YUI for now.
+Defaults to false.
+
+Note that YUI doesn't support rendering nested menu groups, so having direct
+parent/children render_children_inline is likely not going to do what you
+want or expect.
+
 =head2 url
 
 Gets or sets the URL that the menu's link goes to.  If the link
@@ -79,13 +111,12 @@ treated as relative to it's parent's url, and made absolute.
 
 sub url {
     my $self = shift;
-    $self->{url} = shift if @_;
-
-    $self->{url} = URI->new_abs($self->{url}, $self->parent->url . "/")->as_string
-      if $self->parent and $self->parent->url;
-
-    $self->{url} =~ s!///!/! if $self->{url};
-
+    if (@_) {
+        $self->{url} = shift;
+        $self->{url} = URI->new_abs($self->{url}, $self->parent->url . "/")->as_string
+            if defined $self->{url} and $self->parent and $self->parent->url;
+        $self->{url} =~ s!///!/! if $self->{url};
+    }
     return $self->{url};
 }
 
@@ -123,24 +154,38 @@ sub child {
     my $proto = ref $self || $self;
 
     if (@_) {
-        $self->{children}{$key} = $proto->new({parent => $self,
-                                               sort_order => ($self->{children}{$key}{sort_order}
-                                                          || scalar values %{$self->{children}}),
-                                               label => $key,
-                                               escape_label => 1,
-                                               @_
-                                             });
-        Scalar::Util::weaken($self->{children}{$key}{parent});
+        # Clear children ordering cache
+        delete $self->{children_list};
+
+        # Set us up the child
+        my $child = $proto->new({parent => $self,
+                                 sort_order => ($self->{children}{$key}{sort_order}
+                                                    || scalar values %{$self->{children}}),
+                                 label => $key,
+                                 escape_label => 1,
+                                 @_
+                             });
+        $self->{children}{$key} = $child;
+
+        # URL is relative to parents, and cached, so set it up now
+        $child->url($child->{url});
+        
+        # Figure out the URL
+        my $url   =   ( defined $child->link
+                    and ref $child->link
+                    and $child->link->can('url') )
+                        ? $child->link->url : $child->url;
+
         # Activate it
-        if (my $url = $self->{children}{$key}->url and Jifty->web->request) {
+        if ( defined $url and length $url and Jifty->web->request ) {
             # XXX TODO cleanup for mod_perl
             my $base_path = Jifty->web->request->path;
             chomp($base_path);
-        
-            $base_path =~ s/index\.html$//g;
-            $base_path =~ s/\/+$//g;
-            $url =~ s/\/+$//i;
-    
+            
+            $base_path =~ s/index\.html$//;
+            $base_path =~ s/\/+$//;
+            $url =~ s/\/+$//;
+            
             if ($url eq $base_path) {
                 $self->{children}{$key}->active(1); 
             }
@@ -174,6 +219,7 @@ Removes the child with the provided I<KEY>.
 sub delete {
     my $self = shift;
     my $key = shift;
+    delete $self->{children_list};
     delete $self->{children}{$key};
 }
 
@@ -186,12 +232,17 @@ array context, or as an array reference in scalar context.
 
 sub children {
     my $self = shift;
-    my @kids = values %{$self->{children} || {}};
-    @kids = sort {$a->sort_order <=> $b->sort_order} @kids;
+    my @kids;
+    if ($self->{children_list}) {
+        @kids = @{$self->{children_list}};
+    } else {
+        @kids = values %{$self->{children} || {}};
+        @kids = sort {$a->{sort_order} <=> $b->{sort_order}} @kids;
+        $self->{children_list} = \@kids;
+    }
     return wantarray ? @kids : \@kids;
 }
 
-
 =head2 render_as_menu
 
 Render this menu with HTML markup as multiple dropdowns, suitable for
@@ -205,7 +256,7 @@ sub render_as_menu {
     Jifty->web->out(qq{<ul class="menu">});
 
     for (@kids) {
-	$_->render_as_hierarchical_menu_item();
+        $_->render_as_hierarchical_menu_item();
     }
     Jifty->web->out(qq{</ul>});
     '';
@@ -218,11 +269,11 @@ Render this menu with html markup as an inline dropdown menu.
 =cut
 
 sub render_as_context_menu {
-	my $self = shift;
-    	Jifty->web->out( qq{<ul class="context_menu">});
-	$self->render_as_hierarchical_menu_item();
-	Jifty->web->out(qq{</ul>});
-	'';
+    my $self = shift;
+    Jifty->web->out( qq{<ul class="context_menu">});
+    $self->render_as_hierarchical_menu_item();
+    Jifty->web->out(qq{</ul>});
+    '';
 }
 
 =head2 render_as_hierarchical_menu_item
@@ -239,14 +290,15 @@ sub render_as_hierarchical_menu_item {
         @_
     );
     my @kids = $self->children;
-    my $id   = Jifty->web->serial;
-    Jifty->web->out( qq{<li class="toplevel }
+    my $web = Jifty->web;
+    my $id   = $web->serial;
+    $web->out( qq{<li class="toplevel }
             . ( $self->active ? 'active' : 'closed' ) .' '.($self->class||"").' '. qq{">}
             . qq{<span class="title">} );
-    Jifty->web->out( $self->as_link );
-    Jifty->web->out(qq{</span>});
+    $web->out( $self->as_link );
+    $web->out(qq{</span>});
     if (@kids) {
-        Jifty->web->out(
+        $web->out(
             qq{<span class="expand"><a href="#" onclick="Jifty.ContextMenu.hideshow('}
                 . $id
                 . qq{'); return false;">&nbsp;</a></span>}
@@ -254,17 +306,17 @@ sub render_as_hierarchical_menu_item {
                 . $id
                 . qq{">} );
         for (@kids) {
-            Jifty->web->out(qq{<li class="submenu }.($_->active ? 'active' : '' ).' '. ($_->class || "").qq{">});
+            $web->out(qq{<li class="submenu }.($_->active ? 'active' : '' ).' '. ($_->class || "").qq{">});
 
             # We should be able to get this as a string.
             # Either stringify the link object or output the label
             # This is really icky. XXX TODO
-            Jifty->web->out( $_->as_link );
-            Jifty->web->out("</li>");
+            $web->out( $_->as_link );
+            $web->out("</li>");
         }
-        Jifty->web->out(qq{</ul>});
+        $web->out(qq{</ul>});
     }
-    Jifty->web->out(qq{</li>});
+    $web->out(qq{</li>});
     '';
 
 }
@@ -277,13 +329,13 @@ Currently renders one level of submenu, if it exists.
 =cut
 
 sub  render_as_classical_menu {
-	my $self = shift;
+    my $self = shift;
     my @kids = $self->children;
 
     Jifty->web->out( qq{<ul class="menu">});
 
     for (@kids) {
-	    $_->_render_as_classical_menu_item();
+        $_->_render_as_classical_menu_item();
     }
 
     Jifty->web->out(qq{</ul>});
@@ -313,7 +365,7 @@ sub _render_as_classical_menu_item {
 
 }
 
-=head2 render_as_yui_menubar
+=head2 render_as_yui_menubar [PARAMHASH]
 
 Render menubar with YUI menu, suitable for an application's menu.
 It can support arbitary levels of submenu.
@@ -323,10 +375,10 @@ It can support arbitary levels of submenu.
 sub render_as_yui_menubar {
     my $self = shift;
     my $id   = Jifty->web->serial;
-    $self->_render_as_yui_menu_item("yuimenubar", $id);
+    $self->_render_as_yui_menu_item( class => "yuimenubar", id => $id );
     Jifty->web->out(qq|<script type="text/javascript">\n|
         . qq|YAHOO.util.Event.onContentReady("|.$id.qq|", function() {\n|
-        . qq|var menu = new YAHOO.widget.MenuBar("|.$id.qq|", { autosubmenudisplay:true, hidedelay:750, lazyload:true });\n|
+        . qq|var menu = new YAHOO.widget.MenuBar("|.$id.qq|", { autosubmenudisplay:true, hidedelay:750, lazyload:true, showdelay:0 });\n|
         . qq|menu.render();\n|
         . qq|});</script>|
         );
@@ -334,23 +386,87 @@ sub render_as_yui_menubar {
 }
 
 sub _render_as_yui_menu_item {
-    my ($self, $class, $id) = @_;
-    my @kids = $self->children 
-        or return;
+    my $self = shift;
+    my %args = ( class => 'yuimenu', first => 0, id => undef, @_ );
+    my @kids = $self->children or return;
     
-    Jifty->web->out(
-        qq{<div}
-        . ($id ? qq{ id="$id"} : "")
-        . qq{ class="$class"><div class="bd"><ul>}
-    );
-    for (@kids) {
-        Jifty->web->out( qq{<li class="${class}item }
-        . ($_->active? 'active' : '') . qq{">});
-        Jifty->web->out( $_->as_link );
-        $_->_render_as_yui_menu_item("yuimenu");
-        Jifty->web->out( qq{</li>});
+    # Add the appropriate YUI class to each kid
+    for my $kid ( @kids ) {
+        # Skip it if it's a group heading
+        next if $kid->render_children_inline and $kid->children;
+
+        # Figure out the correct object to be setting the class on
+        my $object =   ( defined $kid->link
+                     and ref $kid->link
+                     and $kid->link->can('class') )
+                         ? $kid->link : $kid;
+
+        my $class = defined $object->class ? $object->class . ' ' : '';
+        $class .= "$args{class}itemlabel";
+        $object->class( $class );
+    }
+
+    # We're rendering this inline, so just render a UL (and any submenus as normal)
+    if ( $self->render_children_inline ) {
+        Jifty->web->out( $args{'first'} ? '<ul class="first-of-type">' : '<ul>' );
+        for my $kid ( @kids ) {
+            Jifty->web->out( qq(<li class="$args{class}item ) . ($kid->active? 'active' : '') . qq{">});
+            Jifty->web->out( $kid->as_link );
+            $kid->_render_as_yui_menu_item( class => 'yuimenu' );
+            Jifty->web->out( qq{</li>});
+        }
+        Jifty->web->out('</ul>');
+    }
+    # Render as normal submenus
+    else {
+        Jifty->web->out(
+            qq{<div}
+            . ($args{'id'} ? qq( id="$args{'id'}") : "")
+            . qq( class="$args{class}"><div class="bd">)
+        );
+
+        my $count    = 1;
+        my $count_h6 = 1;
+        my $openlist = 0;
+
+        for my $kid ( @kids ) {
+            # We want to render the children of this child inline, so close
+            # any open <ul>s, render it as an <h6>, and then render it's
+            # children.
+            if ( $kid->render_children_inline and $kid->children ) {
+                Jifty->web->out('</ul>') if $openlist;
+                
+                my @classes = ();
+                push @classes, 'active' if $kid->active;
+                push @classes, 'first-of-type'
+                    if $count_h6 == 1 and $count == 1;
+
+                Jifty->web->out(qq(<h6 class="@{[ join ' ', @classes ]}">));
+                Jifty->web->out( $kid->as_link );
+                Jifty->web->out('</h6>');
+                $kid->_render_as_yui_menu_item(
+                    class => 'yuimenu',
+                    first => ($count == 1 ? 1 : 0)
+                );
+                $openlist = 0;
+                $count_h6++;
+            }
+            # It's a normal child
+            else {
+                if ( not $openlist ) {
+                    Jifty->web->out( $count == 1 ? '<ul class="first-of-type">' : '<ul>' );
+                    $openlist = 1;
+                }
+                Jifty->web->out( qq(<li class="$args{class}item ) . ($kid->active? 'active' : '') . qq{">});
+                Jifty->web->out( $kid->as_link );
+                $kid->_render_as_yui_menu_item( class => 'yuimenu' );
+                Jifty->web->out( qq{</li>});
+            }
+            $count++;
+        }
+        Jifty->web->out('</ul>') if $openlist;
+        Jifty->web->out(qq{</div></div>});
     }
-    Jifty->web->out(qq{</ul></div></div>});
 }
 
 =head2 as_link
