@@ -6,7 +6,10 @@ use base qw/Jifty::Object/;
 use CGI::Cookie ();
 use DateTime ();
 use Storable ();
- 
+$Storable::Deparse = 1;
+$Storable::Eval = 1;
+$Storable::forgive_me = 1;
+
 =head1 NAME
 
 Jifty::Web::Session - A Jifty session handler
@@ -89,24 +92,21 @@ sub load_by_kv {
     my $self = shift;
     my $k    = shift;
     my $v    = shift;
-    my $session_id;
-
-    # tried doing this with load_by_cols but it never returned any rows
-    my $sessions = Jifty::Model::SessionCollection->new;
-    $sessions->limit( column => 'key_type', value => 'key' );
-    $sessions->limit( column => 'data_key', value => $k );
 
     # XXX TODO: we store this data in a storable. so we now want to match on the storable version
     # It would be so nice if Jifty::DBI could do this for us.
-    $Storable::Deparse = 1;
-    my $value = Storable::nfreeze(\$v);
+    my $encoded = Storable::nfreeze(\$v);
 
-    $sessions->limit( column => 'value' => value => $value );
+    my $session = Jifty::Model::Session->new;
+    $session->load_by_cols(
+        key_type => 'key',
+        data_key => $k,
+        value    => $encoded,
+    );
+    my $session_id = $session->session_id;
+
+    # XXX: if $session_id is undef, then bad things happen. This *can* happen.
 
-    while ( my $row = $sessions->next ) {
-        $session_id = $row->session_id;
-        last;
-    }
     $self->load($session_id);
     $self->set( $k => $v ) if !$session_id;
 }
@@ -237,6 +237,21 @@ sub remove {
     $setting->delete if $setting->id;
 }
 
+=head2 remove_all
+
+Removes the session from the database entirely.
+
+=cut
+
+sub remove_all {
+    my $self = shift;
+    return unless $self->loaded;
+    my $settings = Jifty::Model::SessionCollection->new;
+    $settings->limit( column => "session_id", value => $self->id );
+    $_->delete while $_ = $settings->next;
+    $self->unload;
+}
+
 =head2 set_continuation ID CONT
 
 Stores a continuation in the session.
@@ -289,7 +304,7 @@ sub continuations {
     $conts->limit( column => "session_id", value => $self->id );
 
     my %continuations;
-    $continuations{ $_->key } = $_->value while $_ = $conts->next;
+    $continuations{ $_->data_key } = $_->value while $_ = $conts->next;
     return %continuations;
 }
 
@@ -302,6 +317,10 @@ Sets the session cookie.
 sub set_cookie {
     my $self = shift;
 
+    # never send a cookie with cached content. misbehaving proxies cause
+    # terrific problems
+    return if Jifty->handler->apache->header_out('Expires');
+
     my $cookie_name = $self->cookie_name;
     my %cookies     = CGI::Cookie->fetch();
     my $cookie = new CGI::Cookie(
