@@ -7,6 +7,9 @@ use Jifty::DBI::Schema;
 # Mixins
 
 use TestApp::Plugin::PasswordAuth::Record schema {
+   column 'mygroup' =>
+             valid_values are qw/admin moderator user/,
+             default is 'user';
 
 };
 
@@ -17,5 +20,9 @@ use Jifty::Plugin::Authentication::Password::Mixin::Model::User;
 
 # Your model-specific methods go here.
 
+sub current_user_can {
+    return 1;
+};
+
 1;
 
