@@ -2,7 +2,8 @@ package TestApp::Plugin::REST::Dispatcher;
 use Jifty::Dispatcher -base;
 
 before '*' => run {
-    Jifty->api->hide('CreateGroup');
+    Jifty->api->deny('CreateGroup');
+    Jifty->api->hide('DeleteGroup');
     Jifty->api->allow('DoSomething');
 };
 
