@@ -1,11 +1,13 @@
 package TestApp::View::base;
 use Jifty::View::Declare -base;
 
+sub base_path { '/base' }
+
 template 'list_ht' => sub {
     my $self = shift;
     outs("/base/list=$self");
     for (0..1) {
-	$self->has_template('view')->();
+	$self->resolve_template('view')->();
     }
 };
 
@@ -13,7 +15,7 @@ template 'list_s' => sub {
     my $self = shift;
     outs("/base/list=$self");
     for (0..1) {
-	show('view');
+	show($self->base_path.'/view');
     }
 };
 
@@ -21,7 +23,7 @@ template 'list_rg' => sub {
     my $self = shift;
     outs("/base/list=$self");
     for (0..1) {
-	render_region('view-'.$_, path => 'view');
+	render_region('view-'.$_, path => $self->base_path.'/view');
     }
 };
 
